==> piwigo-2.5.1.zip: piwigo/plugins/c13y_upgrade/language/sl_SI/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['c13y_correction_dbl_email_user'] = 'Izbriši podvojene uporabnike';
$lang['c13y_correction_obsolete_plugin'] = '"%s" je vključen v tej verziji aplikancije in ga morate odstraniti';
$lang['c13y_dbl_email_user'] = 'Uporabniki z enakim e-mail naslovom';
$lang['c13y_obsolete_plugin'] = 'Zastareli vtičnik';
$lang['c13y_upgrade_no_anomaly'] = 'Po posodobitvi aplikacije ni bilo zaznati nepravilnosti. Vtičnik "Preveri za nadgradnje" je bil deaktiviran';
?>

==> piwigo-2.5.3.zip: piwigo/plugins/c13y_upgrade/language/sl_SI/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['c13y_correction_dbl_email_user'] = 'Izbriši podvojene uporabnike';
$lang['c13y_correction_obsolete_plugin'] = '"%s" je vključen v tej verziji aplikacije in ga morate odstraniti';
$lang['c13y_dbl_email_user'] = 'Uporabniki z enakim e-mail naslovom';
$lang['c13y_obsolete_plugin'] = 'Zastarel vtičnik';
$lang['c13y_upgrade_no_anomaly'] = 'Po posodobitvi aplikacije ni bilo zaznati nepravilnosti. Vtičnik "Preveri za nadgradnje" je bil deaktiviran';
?>
